@@ -1,14 +1,17 @@
 package Crypt::PBKDF2; 
 # ABSTRACT: The PBKDF2 password hashing algorithm.
-our $VERSION = '0.150900'; # VERSION
+our $VERSION = '0.160410'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-use Moose 1;
-use Moose::Util::TypeConstraints;
+use Moo 2;
+use strictures 2;
 use namespace::autoclean;
 use MIME::Base64 ();
 use Carp qw(croak);
 use Module::Runtime;
 use Try::Tiny;
+use Type::Tiny;
+use Types::Standard qw(Str Int HashRef ConsumerOf);
+use Scalar::Util qw(blessed);
 
 sub BUILD {
   my ($self) = @_;
@@ -18,7 +21,7 @@ sub BUILD {
 
 has hash_class => (
   is => 'ro',
-  isa => 'Str',
+  isa => Str,
   default => 'HMACSHA1',
   predicate => 'has_hash_class',
 );
@@ -26,7 +29,7 @@ has hash_class => (
 
 has hash_args => (
   is => 'ro',
-  isa => 'HashRef',
+  isa => HashRef,
   default => sub { +{} },
   predicate => 'has_hash_args',
 );
@@ -34,14 +37,14 @@ has hash_args => (
 
 has hasher => (
   is => 'ro',
-  isa => role_type('Crypt::PBKDF2::Hash'),
+  isa => ConsumerOf['Crypt::PBKDF2::Hash'],
   lazy => 1,
   default => sub { shift->_lazy_hasher },
 );
 
 has _lazy_hasher => (
   is => 'ro',
-  isa => role_type('Crypt::PBKDF2::Hash'),
+  isa => ConsumerOf['Crypt::PBKDF2::Hash'],
   lazy => 1,
   init_arg => undef,
   predicate => 'has_lazy_hasher',
@@ -62,21 +65,21 @@ sub _build_hasher {
 
 has iterations => (
   is => 'ro',
-  isa => 'Int',
-  default => '1000',
+  isa => Int,
+  default => 1000,
 );
 
 
 has output_len => (
   is => 'ro',
-  isa => 'Int',
+  isa => Int,
   predicate => 'has_output_len',
 );
 
 
 has salt_len => (
   is => 'ro',
-  isa => 'Int',
+  isa => Int,
   default => 4,
 );
 
@@ -92,14 +95,14 @@ sub _random_salt {
 
 has encoding => (
   is => 'ro',
-  isa => 'Str',
+  isa => Str,
   default => 'ldap',
 );
 
 
 has length_limit => (
   is => 'ro',
-  isa => 'Int',
+  isa => Int,
   predicate => 'has_length_limit',
 );
 
@@ -182,7 +185,7 @@ sub PBKDF2_base64 {
 
 sub PBKDF2_hex {
   my $self = shift;
-  return unpack "H*", unpack "a*", $self->PBKDF2(@_);
+  return unpack "H*", $self->PBKDF2(@_);
 }
 
 sub _PBKDF2_F {
@@ -214,7 +217,7 @@ sub encode_string {
 sub _encode_string_cryptlike {
   my ($self, $salt, $hash) = @_;
   my $hasher = $self->hasher;
-  my $hasher_class = Class::MOP::class_of($hasher)->name;
+  my $hasher_class = blessed($hasher);
   if (!defined $hasher_class || $hasher_class !~ s/^Crypt::PBKDF2::Hash:://) {
     croak "Can't ''encode_string'' with a hasher class outside of Crypt::PBKDF2::Hash::*";
   }
@@ -230,7 +233,7 @@ sub _encode_string_cryptlike {
 sub _encode_string_ldaplike {
   my ($self, $salt, $hash) = @_;
   my $hasher = $self->hasher;
-  my $hasher_class = Class::MOP::class_of($hasher)->name;
+  my $hasher_class = blessed($hasher);
   if (!defined $hasher_class || $hasher_class !~ s/^Crypt::PBKDF2::Hash:://) {
     croak "Can't ''encode_string'' with a hasher class outside of Crypt::PBKDF2::Hash::*";
   }
@@ -361,7 +364,7 @@ Crypt::PBKDF2 - The PBKDF2 password hashing algorithm.
 
 =head1 VERSION
 
-version 0.150900
+version 0.160410
 
 =head1 SYNOPSIS
 
@@ -569,7 +572,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Andrew Rodland.
+This software is copyright (c) 2016 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
