@@ -1,8 +1,9 @@
 package Crypt::PBKDF2::Hash;
 # ABSTRACT: Abstract role for PBKDF2 hashing algorithms.
-our $VERSION = '0.150900'; # VERSION
+our $VERSION = '0.160410'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-use Moose::Role;
+use Moo::Role 2;
+use strictures 2;
 use namespace::autoclean;
 
 requires 'hash_len';
@@ -27,7 +28,7 @@ Crypt::PBKDF2::Hash - Abstract role for PBKDF2 hashing algorithms.
 
 =head1 VERSION
 
-version 0.150900
+version 0.160410
 
 =head1 METHODS
 
@@ -59,7 +60,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Andrew Rodland.
+This software is copyright (c) 2016 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
