@@ -1,8 +1,9 @@
 package Crypt::PBKDF2::Hash::DigestHMAC;
 # ABSTRACT: Digest::HMAC hash support for Crypt::PBKDF2.
-our $VERSION = '0.150900'; # VERSION
+our $VERSION = '0.160410'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-use Moose 1;
+use Moo 2;
+use strictures 2;
 use namespace::autoclean;
 use Digest 1.16 ();
 use Digest::HMAC 1.01 ();
@@ -18,8 +19,7 @@ has digest_class => (
 );
 
 has _digest => (
-  is => 'ro',
-  lazy_build => 1,
+  is => 'lazy',
   init_arg => undef,
 );
 
@@ -65,7 +65,6 @@ sub from_algo_string {
   return $class->new(digest_class => $str);
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -80,7 +79,7 @@ Crypt::PBKDF2::Hash::DigestHMAC - Digest::HMAC hash support for Crypt::PBKDF2.
 
 =head1 VERSION
 
-version 0.150900
+version 0.160410
 
 =head1 DESCRIPTION
 
@@ -100,7 +99,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Andrew Rodland.
+This software is copyright (c) 2016 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
