@@ -1,8 +1,9 @@
 package Crypt::PBKDF2::Hash::HMACSHA1;
 # ABSTRACT: HMAC-SHA1 support for Crypt::PBKDF2 using Digest::SHA
-our $VERSION = '0.150900'; # VERSION
+our $VERSION = '0.160410'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-use Moose;
+use Moo 2;
+use strictures 2;
 use namespace::autoclean;
 use Digest::SHA ();
 use Carp qw(croak);
@@ -26,7 +27,6 @@ sub from_algo_string {
   croak "No argument expected";
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -41,7 +41,7 @@ Crypt::PBKDF2::Hash::HMACSHA1 - HMAC-SHA1 support for Crypt::PBKDF2 using Digest
 
 =head1 VERSION
 
-version 0.150900
+version 0.160410
 
 =head1 DESCRIPTION
 
@@ -54,7 +54,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Andrew Rodland.
+This software is copyright (c) 2016 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
