@@ -1,29 +1,28 @@
 package Crypt::PBKDF2::Hash::HMACSHA2;
 # ABSTRACT: HMAC-SHA2 support for Crypt::PBKDF2 using Digest::SHA
-our $VERSION = '0.150900'; # VERSION
+our $VERSION = '0.160410'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
-use Moose 1;
-use Moose::Util::TypeConstraints;
+use Moo 2;
+use strictures 2;
 use namespace::autoclean;
 use Digest::SHA ();
+use Type::Tiny;
+use Types::Standard qw(Enum);
 
 with 'Crypt::PBKDF2::Hash';
 
-subtype 'SHASize' => (
-  as 'Int',
-  where { $_ == 224 or $_ == 256 or $_ == 384 or $_ == 512 },
-  message { "$_ is an invalid number of bits for SHA-2" }
-);
-
 has 'sha_size' => (
   is => 'ro',
-  isa => 'SHASize',
+  isa => Type::Tiny->new(
+    name => 'SHASize',
+    parent => Enum[qw( 224 256 384 512 )],
+    display_name => 'valid number of bits for SHA-2',
+  ),
   default => 256,
 );
 
 has '_hasher' => (
-  is => 'ro',
-  lazy_build => 1,
+  is => 'lazy',
   init_arg => undef,
 );
 
@@ -56,7 +55,6 @@ sub from_algo_string {
   return $class->new( sha_size => $str );
 }
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -71,7 +69,7 @@ Crypt::PBKDF2::Hash::HMACSHA2 - HMAC-SHA2 support for Crypt::PBKDF2 using Digest
 
 =head1 VERSION
 
-version 0.150900
+version 0.160410
 
 =head1 DESCRIPTION
 
@@ -84,7 +82,7 @@ Andrew Rodland <arodland@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Andrew Rodland.
+This software is copyright (c) 2016 by Andrew Rodland.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
